Type: Package
Package: PiC
Title: Pointcloud Interactive Computation
Version: 1.2.7
Authors@R: c(
    person("Roberto", "Ferrara", , "roberto.ferrara@cnr.it", 
           role = c("aut", "cre"), 
           comment = c(ORCID = "0009-0000-3627-6867")),
    person("Stefano", "Arrizza", 
           role = "ctb", 
           comment = c(ORCID = "0009-0009-2290-3650"))
  )
Description: Provides advanced algorithms for analyzing pointcloud data from terrestrial laser scanner in
    forestry applications. Key features include fast voxelization of
    large datasets; segmentation of point clouds into forest floor,
    understorey, canopy, and wood components. The package enables
    efficient processing of large-scale forest pointcloud data, offering
    insights into forest structure, connectivity, and fire risk
    assessment. Algorithms to analyze pointcloud data (.xyz input file).
    For more details, see Ferrara & Arrizza (2025) <https://hdl.handle.net/20.500.14243/533471>.
    For single tree segmentation details, see Ferrara et al. (2018) 
    <doi:10.1016/j.agrformet.2018.04.008>.
License: GPL (>= 3)
Depends: R (>= 4.3)
Imports: collapse, conicfit, data.table, dbscan, dplyr, foreach,
        magrittr, sf, stats, tictoc, utils
Suggests: DT, fs, ggplot2, later, plotly, shiny, shinycssloaders,
        shinydashboard, shinydashboardPlus, shinyFeedback, shinyFiles,
        shinyjs, shinythemes, shinyWidgets, testthat (>= 3.0.0), tools,
        withr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.2
URL: https://github.com/rupppy/PiC
BugReports: https://github.com/rupppy/PiC/issues
NeedsCompilation: no
Packaged: 2025-11-07 14:16:53 UTC; robertoferrara
Author: Roberto Ferrara [aut, cre] (ORCID:
    <https://orcid.org/0009-0000-3627-6867>),
  Stefano Arrizza [ctb] (ORCID: <https://orcid.org/0009-0009-2290-3650>)
Maintainer: Roberto Ferrara <roberto.ferrara@cnr.it>
Repository: CRAN
Date/Publication: 2025-11-07 15:30:08 UTC
Built: R 4.6.0; ; 2026-04-29 06:18:42 UTC; unix
